<p align="center">
  <img src="assets/deduck.png" alt="DeDuck Logo" width="200"/>
</p>

# The DeDuck Prover

A little prover used in CS 245 at the University of Waterloo.
DeDuck lets the user program formal-deduction proofs and have them checked by the prover.
A [VS Code extension](https://github.com/deduck-prover/deduck-vscode) provides a simple interface for programming and checking proofs interactively with the prover.

## Installation

```bash
pip install deduck-prover
```

## Documentation
A reference manual of the available axioms and theorems is [available](docs/rules_usage.md).

## License

This project is licensed under the MIT License. See the LICENSE file for details.
